==> open-sysclone_0.2.tar.gz: open-sysclone-0.2/open-sysclone-gui.install/usr/share/open-sysclone-gui/js/restore_image_multicast.js <==
/* Class definition*/
function RestoreImageManagerMulticast(){
	
	/*Esential definition*/
	
	var self = this;

		
	
	this.BindLoginEventHandlers = function(){
		
		/*Define actions for buttons*/
		
		$("#goback").bind('click',this.goback);
		$("#restoreimagemulticast").bind('click',this.restoreimagemulticast);
		
		
		var pathfile = 'imagenes';

		/*This function list Images in path_file defined by defect as imagenes*/
		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'list_img',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",pathfile],
				success: function(response,status,jqXHR){
					result=response[0][0];
					if (result){
						response[0][1].forEach(function (item){
							var aux_option = $(document.createElement('option')).val(item).html(item);
							$("#imagename").append(aux_option);
						});
					}
					else {
						var aux_option = $(document.createElement('option')).html('Not yet image');
						$("#imagename").append(aux_option);
						$("#imagename").prop('disabled','disabled');
						
					}
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
		});
	}
	

	/*this function is for buttom goback*/
	
	this.goback = function (event){
		window.location='main.html';
	}
	

	/*This function is the main process when click done button*/
	
	this.restoreimagemulticast = function (){
		var imgname = $("#imagename").val();
		var imagehdd = $("#imagehdd").val();
		var finaloperation = $("#finaloperation").val();
		var clientswait = $("#clientswait").val();
		var timemax = $("#timemax").val();
		var pathfile = 'imagenes';

		console.log("Valores de las variables al inicio del programa ",imgname,imagehdd,finaloperation,clientswait,timemax,pathfile);

		console.log(imgname);
		if (pathfile === ""){
			console.log("Please insert the pathfile of image to restore");
			return false;
		}
		if (imgname === ""){
			console.log("Please insert the name of image to restore");
			return false;
		}
		if (imagehdd === ""){
			console.log("You don't tell my the HDD to restore image");
			return false;
		}
		if (clientswait === ""){
			console.log("You don't tell my the number of clients to restore image");
			return false;
		}
		if (timemax === ""){
			console.log("You don't tell my the time to wait to restore image");
			return false;
		}

		/*Now we call n4d in server and print menu PXE*/
		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'nfs_export_start',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",pathfile],
				success: function(response,status,jqXHR){
					result=response[0][0];
					if (result){
						console.log("Valores de las variables dentro del primer if ",imgname,imagehdd,finaloperation,clientswait,timemax);
						self.write_menu_pxe(imgname,imagehdd,finaloperation,clientswait,timemax);
					}
					else{
						console.log("ha habido un error en la primera",response[0]);
					}
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
			});


	}


	/*This function call n4d in server for RestoreImageMulticast method*/
	
	this.write_menu_pxe = function (name,hdd,finaloperation,clientsw,timer){
		
		/*by defect OpenSysClone work in /net/OpenSysClone/imagenes, defined /net/OpenSysClone in n4d_python_plugins and pathfile=imagenes*/
		var pathfile = 'imagenes';
		
		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'write_menu_pxe',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",'RestoreImageMulticast.tpl',pathfile,name,hdd,finaloperation],
				success: function(response,status,jqXHR){
					result=response[0][0];
					if (result){
						
						self.send_multicast_file(pathfile,name,clientsw,timer);
					}
					else{
						console.log("ha habido un error escribiendo el menu PXE",response[0]);
					}
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
			});
	}



	/*This function call n4d in server for send_multicast_file method*/

	this.send_multicast_file = function (pathfiler,namer,clients,time){
		
		console.log("Valores de las variables dentro de la funcion ",pathfiler,namer,clients,time);

		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'send_multicast_file',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",pathfiler,namer,clients,time],
				success: function(response,status,jqXHR){
					//vacio la variable que me informara del resultado
					$('#result').empty();

					result=response[0][0];
					if (result){
						console.log("todo ha ido bien");
						var img = $(document.createElement('img')).attr('src','img/ok.png');
					}
					else{
						console.log("ha habido un error en la ejecucion de multicast " +response[0]);
						var img = $(document.createElement('img')).attr('src','img/fail.png');
					}
					//Añado los valores al identificador que me mostrara la respuesta por pantalla
					//Especificamos el tamaño de la imagen
					img.attr('style',"width: 15px; height: 15px; margin: 5px;");
					//añado a la variable text la respuesta de N4D
					var text = $(document.createElement('span')).html(response[0][1]);
					//Uno la imagen y el texto dentro del identificador de la web result
					$('#result').append(img);
					$('#result').append(text);
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
			});
	}

	
}

/*Main*/

$(document).ready(function() {
	var rimm = new RestoreImageManagerMulticast();
	rimm.BindLoginEventHandlers();
});

==> open-sysclone_0.47.tar.gz: open-sysclone-0.47/open-sysclone-gui.install/usr/share/open-sysclone-gui/js/restore_image_multicast.js <==
/* Class definition*/
function RestoreImageManagerMulticast(){
	
	/*Esential definition*/
	
	var self = this;

		
	
	this.BindLoginEventHandlers = function(){
		
		/*Define actions for buttons*/
		
		$("#goback").bind('click',this.goback);
		$("#restoreimagemulticast").bind('click',this.restoreimagemulticast);
		
		
		var pathfile = 'imagenes';

		/*This function list Images in path_file defined by defect as imagenes*/
		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'list_img',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",pathfile],
				success: function(response,status,jqXHR){
					result=response[0][0];
					if (result){
						response[0][1].forEach(function (item){
							var aux_option = $(document.createElement('option')).val(item).html(item);
							$("#imagename").append(aux_option);
						});
					}
					else {
						var aux_option = $(document.createElement('option')).html('Not yet image');
						$("#imagename").append(aux_option);
						$("#imagename").prop('disabled','disabled');
						
					}
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
		});
	}
	

	/*this function is for buttom goback*/
	
	this.goback = function (event){
		window.location='main.html';
	}
	

	/*This function is the main process when click done button*/
	
	this.restoreimagemulticast = function (){
		var imgname = $("#imagename").val();
		var imagehdd = $("#imagehdd").val();
		var finaloperation = $("#finaloperation").val();
		var clientswait = $("#clientswait").val();
		var timemax = $("#timemax").val();
		var pathfile = 'imagenes';
		var hostoperation = $("#hostoperation").val();

		console.log("Valores de las variables al inicio del programa ",imgname,imagehdd,finaloperation,clientswait,timemax,pathfile);

		console.log(imgname);
		if (pathfile === ""){
			console.log("Please insert the pathfile of image to restore");
			return false;
		}
		if (imgname === ""){
			console.log("Please insert the name of image to restore");
			return false;
		}
		if (imagehdd === ""){
			console.log("You don't tell my the HDD to restore image");
			$('#result').empty();
			var img = $(document.createElement('img')).attr('src','img/fail.png');
			//Añado los valores al identificador que me mostrara la respuesta por pantalla
			//Especificamos el tamaño de la imagen
			img.attr('style',"width: 15px; height: 15px; margin: 5px;");
			//añado a la variable text la respuesta de N4D
			var text =  document.createTextNode("You don't tell my the HDD to restore image");
			//Uno la imagen y el texto dentro del identificador de la web result
			$('#result').append(img);
			$('#result').append(text);
			return false;
		}
		if (clientswait === ""){
			console.log("You don't tell my the number of clients to restore image");
			$('#result').empty();
			var img = $(document.createElement('img')).attr('src','img/fail.png');
			//Añado los valores al identificador que me mostrara la respuesta por pantalla
			//Especificamos el tamaño de la imagen
			img.attr('style',"width: 15px; height: 15px; margin: 5px;");
			//añado a la variable text la respuesta de N4D
			var text =  document.createTextNode("You don't tell my the number of clients to restore image");
			//Uno la imagen y el texto dentro del identificador de la web result
			$('#result').append(img);
			$('#result').append(text);
			return false;
		}
		if (timemax === ""){
			console.log("You don't tell my the time to wait to restore image");
			$('#result').empty();
			var img = $(document.createElement('img')).attr('src','img/fail.png');
			//Añado los valores al identificador que me mostrara la respuesta por pantalla
			//Especificamos el tamaño de la imagen
			img.attr('style',"width: 15px; height: 15px; margin: 5px;");
			//añado a la variable text la respuesta de N4D
			var text =  document.createTextNode("You don't tell my the time to wait to restore image");
			//Uno la imagen y el texto dentro del identificador de la web result
			$('#result').append(img);
			$('#result').append(text);
			return false;
		}

		/*Now we call n4d in server and print menu PXE*/
		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'nfs_export_start',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",pathfile],
				success: function(response,status,jqXHR){
					result=response[0][0];
					if (result){
						console.log("Valores de las variables dentro del primer if ",imgname,imagehdd,finaloperation,clientswait,timemax);
						self.write_menu_pxe(imgname,imagehdd,finaloperation,clientswait,timemax,hostoperation);
					}
					else{
						console.log("ha habido un error en la primera",response[0]);
					}
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
			});


	}


	/*This function call n4d in server for RestoreImageMulticast method*/
	
	this.write_menu_pxe = function (name,hdd,finaloperation,clientsw,timer,hostoperation){
		
		/*by defect OpenSysClone work in /net/OpenSysClone/imagenes, defined /net/OpenSysClone in n4d_python_plugins and pathfile=imagenes*/
		var pathfile = 'imagenes';
		
		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'write_menu_pxe',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",'RestoreImageMulticast.tpl',pathfile,name,hdd,finaloperation,hostoperation],
				success: function(response,status,jqXHR){
					result=response[0][0];
					if (result){
						
						self.send_multicast_file(pathfile,name,clientsw,timer);
					}
					else{
						console.log("ha habido un error escribiendo el menu PXE",response[0]);
					}
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
			});
	}



	/*This function call n4d in server for send_multicast_file method*/

	this.send_multicast_file = function (pathfiler,namer,clients,time){
		
		console.log("Valores de las variables dentro de la funcion ",pathfiler,namer,clients,time);

		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'send_multicast_file',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",pathfiler,namer,clients,time],
				success: function(response,status,jqXHR){
					//vacio la variable que me informara del resultado
					$('#result').empty();

					result=response[0][0];
					if (result){
						console.log("todo ha ido bien");
						var img = $(document.createElement('img')).attr('src','img/ok.png');
					}
					else{
						console.log("ha habido un error en la ejecucion de multicast " +response[0]);
						var img = $(document.createElement('img')).attr('src','img/fail.png');
					}
					//Añado los valores al identificador que me mostrara la respuesta por pantalla
					//Especificamos el tamaño de la imagen
					img.attr('style',"width: 15px; height: 15px; margin: 5px;");
					//añado a la variable text la respuesta de N4D
					var text = $(document.createElement('span')).html(response[0][1]);
					//Uno la imagen y el texto dentro del identificador de la web result
					$('#result').append(img);
					$('#result').append(text);
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
			});
	}

	
}

/*Main*/

$(document).ready(function() {
	var rimm = new RestoreImageManagerMulticast();
	rimm.BindLoginEventHandlers();
});
